@@ -1,14 +1,14 @@
 #' Identify closest intervals.
 #'
-#' @param x [tbl_interval()]
-#' @param y [tbl_interval()]
+#' @param x [ivl_df]
+#' @param y [ivl_df]
 #' @param overlap report overlapping intervals
 #' @param suffix colname suffixes in output
 #'
 #' @template groups
 #'
 #' @return
-#' [tbl_interval()] with additional columns:
+#' [ivl_df] with additional columns:
 #'   - `.dist` distance to closest interval. Negative distances
 #'     denote upstream intervals.
 #'   - `.overlap` overlap with closest interval
@@ -18,12 +18,12 @@
 #' @seealso \url{http://bedtools.readthedocs.io/en/latest/content/tools/closest.html}
 #'
 #' @examples
-#' x <- trbl_interval(
+#' x <- tibble::tribble(
 #'   ~chrom, ~start, ~end,
 #'   'chr1', 100,    125
 #' )
 #'
-#' y <- trbl_interval(
+#' y <- tibble::tribble(
 #'   ~chrom, ~start, ~end,
 #'   'chr1', 25,     50,
 #'   'chr1', 140,    175
@@ -31,13 +31,13 @@
 #'
 #' bed_glyph(bed_closest(x, y))
 #'
-#' x <- trbl_interval(
+#' x <- tibble::tribble(
 #'   ~chrom, ~start, ~end,
 #'   "chr1", 500,    600,
 #'   "chr2", 5000,   6000
 #' )
 #'
-#' y <- trbl_interval(
+#' y <- tibble::tribble(
 #'   ~chrom, ~start, ~end,
 #'   "chr1", 100,    200,
 #'   "chr1", 150,    200,
@@ -50,12 +50,12 @@
 #' bed_closest(x, y, overlap = FALSE)
 #'
 #' # Report distance based on strand
-#' x <- trbl_interval(
+#' x <- tibble::tribble(
 #'   ~chrom, ~start, ~end, ~name, ~score, ~strand,
 #'   "chr1", 10,	   20,   "a",   1,      "-"
 #' )
 #'
-#' y <- trbl_interval(
+#' y <- tibble::tribble(
 #'   ~chrom, ~start, ~end, ~name, ~score, ~strand,
 #'   "chr1", 8,	     9,	   "b",   1,      "+",
 #'   "chr1", 21,	   22,	 "b",   1,      "-"
@@ -74,8 +74,8 @@
 #' @export
 bed_closest <- function(x, y, overlap = TRUE,
                         suffix = c(".x", ".y")) {
-  if (!is.tbl_interval(x)) x <- as.tbl_interval(x)
-  if (!is.tbl_interval(y)) y <- as.tbl_interval(y)
+  x <- check_interval(x)
+  y <- check_interval(y)
 
   check_suffix(suffix)
 
@@ -96,10 +96,6 @@ bed_closest <- function(x, y, overlap = TRUE,
 
   suffix <- list(x = suffix[1], y = suffix[2])
 
-  if (utils::packageVersion("dplyr") < "0.7.99.9000"){
-    x <- update_groups(x)
-    y <- update_groups(y)
-  }
   grp_indexes <- shared_group_indexes(x, y)
 
   res <- closest_impl(x, y,
